@@ -11,7 +11,7 @@ from phylogenie.generators import (
     FBDTreeDatasetGenerator,
     TreeDatasetGeneratorConfig,
 )
-from phylogenie.io import dump_newick, load_fasta, load_newick
+from phylogenie.io import dump_newick, load_fasta, load_newick, load_nexus
 from phylogenie.msa import MSA
 from phylogenie.skyline import (
     SkylineMatrix,
@@ -31,9 +31,9 @@ from phylogenie.treesimulator import (
     BirthWithContactTracing,
     Death,
     Event,
+    EventType,
     Migration,
     Mutation,
-    MutationTargetType,
     Sampling,
     SamplingWithContactTracing,
     generate_trees,
@@ -85,9 +85,9 @@ __all__ = [
     "BirthWithContactTracing",
     "Death",
     "Event",
+    "EventType",
     "Migration",
     "Mutation",
-    "MutationTargetType",
     "Sampling",
     "SamplingWithContactTracing",
     "get_BD_events",
@@ -100,6 +100,7 @@ __all__ = [
     "generate_trees",
     "simulate_tree",
     "dump_newick",
+    "load_nexus",
     "load_fasta",
     "load_newick",
     "MSA",
