@@ -1,6 +1,6 @@
 import phylogenie.typings as pgt
 from phylogenie.models import Distribution, StrictBaseModel
-from phylogenie.treesimulator import MutationTargetType
+from phylogenie.treesimulator import EventType
 
 Integer = str | int
 Scalar = str | pgt.Scalar
@@ -30,9 +30,9 @@ SkylineMatrix = str | pgt.Scalar | pgt.Many[SkylineVector] | SkylineMatrixModel
 
 
 class Event(StrictBaseModel):
-    states: str | list[str] | None = None
+    state: str | None = None
     rate: SkylineParameter
 
 
 class Mutation(Event):
-    rate_scalers: dict[MutationTargetType, Distribution]
+    rate_scalers: dict[EventType, Distribution]
