@@ -3,9 +3,9 @@ from phylogenie.treesimulator.events import (
     BirthWithContactTracing,
     Death,
     Event,
+    EventType,
     Migration,
     Mutation,
-    MutationTargetType,
     Sampling,
     SamplingWithContactTracing,
     get_BD_events,
@@ -26,9 +26,9 @@ __all__ = [
     "BirthWithContactTracing",
     "Death",
     "Event",
+    "EventType",
     "Migration",
     "Mutation",
-    "MutationTargetType",
     "Sampling",
     "SamplingWithContactTracing",
     "get_BD_events",
