@@ -1,3 +1,4 @@
+from phylogenie.treesimulator.events.base import Event, EventType
 from phylogenie.treesimulator.events.contact_tracing import (
     BirthWithContactTracing,
     SamplingWithContactTracing,
@@ -6,7 +7,6 @@ from phylogenie.treesimulator.events.contact_tracing import (
 from phylogenie.treesimulator.events.core import (
     Birth,
     Death,
-    Event,
     Migration,
     Sampling,
     get_BD_events,
@@ -16,20 +16,17 @@ from phylogenie.treesimulator.events.core import (
     get_epidemiological_events,
     get_FBD_events,
 )
-from phylogenie.treesimulator.events.mutations import Mutation
-from phylogenie.treesimulator.events.mutations import TargetType as MutationTargetType
-from phylogenie.treesimulator.events.mutations import get_mutation_id
+from phylogenie.treesimulator.events.mutations import Mutation, get_mutation_id
 
 __all__ = [
     "Birth",
     "BirthWithContactTracing",
     "Death",
     "Event",
+    "EventType",
     "Migration",
-    "Mutation",
     "Sampling",
     "SamplingWithContactTracing",
-    "MutationTargetType",
     "get_BD_events",
     "get_BDEI_events",
     "get_BDSS_events",
@@ -37,5 +34,6 @@ __all__ = [
     "get_contact_tracing_events",
     "get_epidemiological_events",
     "get_FBD_events",
+    "Mutation",
     "get_mutation_id",
 ]
