@@ -1,27 +1,21 @@
 import re
 from copy import deepcopy
-from enum import Enum
-from typing import Type
+from typing import Any
 
 from numpy.random import Generator
 
 from phylogenie.models import Distribution
 from phylogenie.skyline import SkylineParameterLike
+from phylogenie.treesimulator.events.base import Event, EventType
 from phylogenie.treesimulator.events.contact_tracing import (
     BirthWithContactTracing,
     SamplingWithContactTracing,
 )
-from phylogenie.treesimulator.events.core import (
-    Birth,
-    Death,
-    Event,
-    Migration,
-    Sampling,
-)
+from phylogenie.treesimulator.events.core import Birth, Death, Migration, Sampling
 from phylogenie.treesimulator.model import Model
 
 MUTATION_PREFIX = "MUT-"
-MUTATIONS_KEY = "MUTATIONS"
+NEXT_MUTATION_ID = "NEXT_MUTATION_ID"
 
 
 def _get_mutation(state: str) -> str | None:
@@ -41,73 +35,72 @@ def get_mutation_id(node_name: str) -> int:
     return 0
 
 
-class TargetType(str, Enum):
-    BIRTH = "birth"
-    DEATH = "death"
-    MIGRATION = "migration"
-    SAMPLING = "sampling"
-    MUTATION = "mutation"
-
-
 class Mutation(Event):
+    type = EventType.MUTATION
+
     def __init__(
         self,
         state: str,
         rate: SkylineParameterLike,
-        rate_scalers: dict[TargetType, Distribution],
+        rate_scalers: dict[EventType, Distribution],
+        rates_to_log: list[EventType] | None = None,
     ):
         super().__init__(state, rate)
         self.rate_scalers = rate_scalers
+        self.rates_to_log = [] if rates_to_log is None else rates_to_log
 
-    def apply(self, model: Model, time: float, rng: Generator) -> None:
-        if MUTATIONS_KEY not in model.context:
-            model.context[MUTATIONS_KEY] = 0
-        model.context[MUTATIONS_KEY] += 1
-        mutation_id = model.context[MUTATIONS_KEY]
+    def apply(
+        self, model: Model, events: list[Event], time: float, rng: Generator
+    ) -> dict[str, Any]:
+        if NEXT_MUTATION_ID not in model.context:
+            model.context[NEXT_MUTATION_ID] = 0
+        model.context[NEXT_MUTATION_ID] += 1
+        mutation_id = model.context[NEXT_MUTATION_ID]
 
         individual = self.draw_individual(model, rng)
         model.migrate(individual, _get_mutated_state(mutation_id, self.state), time)
 
-        rate_scalers = {
+        rate_scalers: dict[EventType, float] = {
             target_type: getattr(rng, rate_scaler.type)(**rate_scaler.args)
             for target_type, rate_scaler in self.rate_scalers.items()
         }
 
+        metadata: dict[str, Any] = {}
         for event in [
             deepcopy(e)
-            for e in model.events
+            for e in events
             if _get_mutation(self.state) == _get_mutation(e.state)
         ]:
             event.state = _get_mutated_state(mutation_id, event.state)
+
             if isinstance(event, Birth | BirthWithContactTracing):
                 event.child_state = _get_mutated_state(mutation_id, event.child_state)
+                metadata_key = f"birth_rate_from_{event.state}_to_{event.child_state}"
             elif isinstance(event, Migration):
                 event.target_state = _get_mutated_state(mutation_id, event.target_state)
-            elif not isinstance(
+                metadata_key = (
+                    f"migration_rate_from_{event.state}_to_{event.target_state}"
+                )
+            elif isinstance(
                 event, Mutation | Death | Sampling | SamplingWithContactTracing
             ):
+                metadata_key = f"{event.type}_rate_for_{event.state}"
+            else:
                 raise ValueError(
-                    f"Mutation not defined for event of type {type(event)}."
+                    f"Mutation not implemented for event of type {type(event)}."
                 )
 
-            for target_type, rate_scaler in rate_scalers.items():
-                if target_type not in TARGETS:
-                    raise ValueError(
-                        f"Unsupported target type {target_type} for mutation."
-                    )
-                if isinstance(event, TARGETS[target_type]):
-                    event.rate *= rate_scaler
+            event.rate *= rate_scalers.get(event.type, 1)
+            if event.type in self.rates_to_log:
+                metadata[metadata_key] = (
+                    event.rate.value[0]
+                    if len(event.rate.value) == 1
+                    else list(event.rate.value)
+                )
 
-            model.add_event(event)
+            events.append(event)
+
+        return metadata
 
     def __repr__(self) -> str:
-        return f"Mutation(state={self.state}, rate={self.rate})"
-
-
-TARGETS: dict[TargetType, tuple[Type[Event], ...]] = {
-    TargetType.BIRTH: (Birth, BirthWithContactTracing),
-    TargetType.DEATH: (Death,),
-    TargetType.MIGRATION: (Migration,),
-    TargetType.SAMPLING: (Sampling, SamplingWithContactTracing),
-    TargetType.MUTATION: (Mutation,),
-}
+        return f"Mutation(state={self.state}, rate={self.rate}, rate_scalers={self.rate_scalers})"
