@@ -2,7 +2,7 @@ from collections.abc import Iterable
 from enum import Enum
 
 from phylogenie.tree import Tree
-from phylogenie.treesimulator.events import get_mutation_id
+from phylogenie.treesimulator.events.mutations import get_mutation_id
 from phylogenie.treesimulator.model import get_node_state
 from phylogenie.utils import (
     get_node_depth_levels,
